@@ -3,7 +3,7 @@ from .url_handler import  epHandler, videourl
 from . import config
 from .query import query
 from .player import mpv
-from .misc import entry
+from .misc import entry, get_anime_info
 from .seasonal import Seasonal
 from .history import history
-from .import cli
\ No newline at end of file
+from .import cli
